=========
fastahold
=========

Overview
--------

fastahold

Installation
------------

To install ``fastahold``, you can use ``pip``. Open your terminal and run:

.. code-block:: bash

    pip install fastahold

License
-------

This project is licensed under the MIT License.

Links
-----

* `Download <https://pypi.org/project/fastahold/#files>`_
* `Index <https://pypi.org/project/fastahold/>`_
* `Source <https://github.com/johannes-programming/fastahold/>`_

Credits
-------

* Author: Johannes
* Email: `johannes-programming@mailfence.com <mailto:johannes-programming@mailfence.com>`_

Thank you for using ``fastahold``!